[CalendarServer-changes] [14488] CalendarServer/branches/users/cdaboo/pod2pod-migration/txdav

source_changes at macosforge.org source_changes at macosforge.org
Sat Feb 28 08:38:15 PST 2015


Revision: 14488
          http://trac.calendarserver.org//changeset/14488
Author:   cdaboo at apple.com
Date:     2015-02-28 08:38:15 -0800 (Sat, 28 Feb 2015)
Log Message:
-----------
Checkpoint: group sharee reconcile.

Modified Paths:
--------------
    CalendarServer/branches/users/cdaboo/pod2pod-migration/txdav/caldav/datastore/sql.py
    CalendarServer/branches/users/cdaboo/pod2pod-migration/txdav/caldav/datastore/sql_directory.py
    CalendarServer/branches/users/cdaboo/pod2pod-migration/txdav/caldav/datastore/sql_external.py
    CalendarServer/branches/users/cdaboo/pod2pod-migration/txdav/common/datastore/podding/migration/home_sync.py
    CalendarServer/branches/users/cdaboo/pod2pod-migration/txdav/common/datastore/podding/migration/test/accounts/groupAccounts.xml
    CalendarServer/branches/users/cdaboo/pod2pod-migration/txdav/common/datastore/podding/migration/test/test_home_sync.py
    CalendarServer/branches/users/cdaboo/pod2pod-migration/txdav/common/datastore/podding/store_api.py
    CalendarServer/branches/users/cdaboo/pod2pod-migration/txdav/common/datastore/podding/test/util.py

Added Paths:
-----------
    CalendarServer/branches/users/cdaboo/pod2pod-migration/txdav/common/datastore/podding/migration/test/accounts/augments.xml

Modified: CalendarServer/branches/users/cdaboo/pod2pod-migration/txdav/caldav/datastore/sql.py
===================================================================
--- CalendarServer/branches/users/cdaboo/pod2pod-migration/txdav/caldav/datastore/sql.py	2015-02-27 22:12:30 UTC (rev 14487)
+++ CalendarServer/branches/users/cdaboo/pod2pod-migration/txdav/caldav/datastore/sql.py	2015-02-28 16:38:15 UTC (rev 14488)
@@ -14,8 +14,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 ##
-from txdav.caldav.datastore.sql_attachment import Attachment, DropBoxAttachment, \
-    AttachmentLink, ManagedAttachment
 
 
 """
@@ -63,7 +61,10 @@
 from txdav.caldav.datastore.scheduling.icalsplitter import iCalSplitter
 from txdav.caldav.datastore.scheduling.implicit import ImplicitScheduler
 from txdav.caldav.datastore.scheduling.utils import uidFromCalendarUserAddress
-from txdav.caldav.datastore.sql_directory import GroupAttendeeRecord
+ffrom txdav.caldav.datastore.sql_attachment import Attachment, DropBoxAttachment, \
+    AttachmentLink, ManagedAttachment
+rom txdav.caldav.datastore.sql_directory import GroupAttendeeRecord,\
+    GroupShareeRecord
 from txdav.caldav.datastore.util import normalizationLookup
 from txdav.caldav.datastore.util import CalendarObjectBase
 from txdav.caldav.datastore.util import dropboxIDFromCalendarObject
@@ -79,6 +80,7 @@
     UnknownTimezone, SetComponentOptions
 from txdav.common.datastore.sql import CommonHome, CommonHomeChild, \
     CommonObjectResource, ECALENDARTYPE
+from txdav.common.datastore.sql_directory import GroupsRecord
 from txdav.common.datastore.sql_tables import _ATTACHMENTS_MODE_NONE, \
     _ATTACHMENTS_MODE_READ, _ATTACHMENTS_MODE_WRITE, _BIND_MODE_DIRECT, \
     _BIND_MODE_GROUP, _BIND_MODE_GROUP_READ, _BIND_MODE_GROUP_WRITE, \
@@ -2315,6 +2317,14 @@
         returnValue(invitations)
 
 
+    @inlineCallbacks
+    def groupSharees(self):
+        sharees = yield GroupShareeRecord.querysimple(self._txn, calendarID=self.id())
+        groups = set([sharee.groupID for sharee in sharees])
+        groups = (yield GroupsRecord.query(self._txn, GroupsRecord.groupID.In(groups))) if groups else []
+        returnValue({"groups": groups, "sharees": sharees})
+
+
 icalfbtype_to_indexfbtype = {
     "UNKNOWN"         : 0,
     "FREE"            : 1,

Modified: CalendarServer/branches/users/cdaboo/pod2pod-migration/txdav/caldav/datastore/sql_directory.py
===================================================================
--- CalendarServer/branches/users/cdaboo/pod2pod-migration/txdav/caldav/datastore/sql_directory.py	2015-02-27 22:12:30 UTC (rev 14487)
+++ CalendarServer/branches/users/cdaboo/pod2pod-migration/txdav/caldav/datastore/sql_directory.py	2015-02-28 16:38:15 UTC (rev 14488)
@@ -62,3 +62,12 @@
             results.append((groupAttendeeRecord, groupsRecord,))
 
         returnValue(results)
+
+
+
+class GroupShareeRecord(SerializableRecord, fromTable(schema.GROUP_SHAREE)):
+    """
+    @DynamicAttrs
+    L{Record} for L{schema.GROUP_SHAREE}.
+    """
+    pass

Modified: CalendarServer/branches/users/cdaboo/pod2pod-migration/txdav/caldav/datastore/sql_external.py
===================================================================
--- CalendarServer/branches/users/cdaboo/pod2pod-migration/txdav/caldav/datastore/sql_external.py	2015-02-27 22:12:30 UTC (rev 14487)
+++ CalendarServer/branches/users/cdaboo/pod2pod-migration/txdav/caldav/datastore/sql_external.py	2015-02-28 16:38:15 UTC (rev 14488)
@@ -24,7 +24,7 @@
 
 from txdav.caldav.datastore.sql import CalendarHome, Calendar, CalendarObject
 from txdav.caldav.datastore.sql_attachment import Attachment, AttachmentLink
-from txdav.caldav.datastore.sql_directory import GroupAttendeeRecord
+from txdav.caldav.datastore.sql_directory import GroupAttendeeRecord, GroupShareeRecord
 from txdav.caldav.icalendarstore import ComponentUpdateState, ComponentRemoveState
 from txdav.common.datastore.sql_directory import GroupsRecord
 from txdav.common.datastore.sql_external import CommonHomeExternal, CommonHomeChildExternal, \
@@ -194,10 +194,16 @@
     """
     SQL-based implementation of L{ICalendar}.
     """
-    pass
 
+    @inlineCallbacks
+    def groupSharees(self):
+        results = yield self._txn.store().conduit.send_homechild_group_sharees(self)
+        results["groups"] = [GroupsRecord.deserialize(items) for items in results["groups"]]
+        results["sharees"] = [GroupShareeRecord.deserialize(items) for items in results["sharees"]]
+        returnValue(results)
 
 
+
 class CalendarObjectExternal(CommonObjectResourceExternal, CalendarObject):
     """
     SQL-based implementation of L{ICalendarObject}.

Modified: CalendarServer/branches/users/cdaboo/pod2pod-migration/txdav/common/datastore/podding/migration/home_sync.py
===================================================================
--- CalendarServer/branches/users/cdaboo/pod2pod-migration/txdav/common/datastore/podding/migration/test/accounts/augments.xml	                        (rev 0)
+++ CalendarServer/branches/users/cdaboo/pod2pod-migration/txdav/common/datastore/podding/migration/test/accounts/augments.xml	2015-02-28 16:38:15 UTC (rev 14488)
@@ -0,0 +1,142 @@
+<?xml version="1.0" encoding="utf-8"?>
+
+<!--
+Copyright (c) 2009-2015 Apple Inc. All rights reserved.
+
+Licensed under the Apache License, Version 2.0 (the "License");
+you may not use this file except in compliance with the License.
+You may obtain a copy of the License at
+
+    http://www.apache.org/licenses/LICENSE-2.0
+
+Unless required by applicable law or agreed to in writing, software
+distributed under the License is distributed on an "AS IS" BASIS,
+WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+See the License for the specific language governing permissions and
+limitations under the License.
+ -->
+
+<!DOCTYPE augments SYSTEM "../../../conf/auth/augments.dtd">
+
+<augments>
+	<record>
+	    <uid>user01</uid>
+	    <server-id>A</server-id>
+	    <enable-calendar>true</enable-calendar>
+	    <enable-addressbook>true</enable-addressbook>
+	</record>
+	<record>
+	    <uid>user02</uid>
+	    <server-id>A</server-id>
+	    <enable-calendar>true</enable-calendar>
+	    <enable-addressbook>true</enable-addressbook>
+	</record>
+	<record>
+	    <uid>user03</uid>
+	    <server-id>A</server-id>
+	    <enable-calendar>true</enable-calendar>
+	    <enable-addressbook>true</enable-addressbook>
+	</record>
+	<record>
+	    <uid>user04</uid>
+	    <server-id>A</server-id>
+	    <enable-calendar>true</enable-calendar>
+	    <enable-addressbook>true</enable-addressbook>
+	</record>
+	<record>
+	    <uid>user05</uid>
+	    <server-id>A</server-id>
+	    <enable-calendar>true</enable-calendar>
+	    <enable-addressbook>true</enable-addressbook>
+	</record>
+	<record>
+	    <uid>user06</uid>
+	    <server-id>A</server-id>
+	    <enable-calendar>true</enable-calendar>
+	    <enable-addressbook>true</enable-addressbook>
+	</record>
+	<record>
+	    <uid>user07</uid>
+	    <server-id>A</server-id>
+	    <enable-calendar>true</enable-calendar>
+	    <enable-addressbook>true</enable-addressbook>
+	</record>
+	<record>
+	    <uid>user08</uid>
+	    <server-id>A</server-id>
+	    <enable-calendar>true</enable-calendar>
+	    <enable-addressbook>true</enable-addressbook>
+	</record>
+	<record>
+	    <uid>user09</uid>
+	    <server-id>A</server-id>
+	    <enable-calendar>true</enable-calendar>
+	    <enable-addressbook>true</enable-addressbook>
+	</record>
+	<record>
+	    <uid>user10</uid>
+	    <server-id>A</server-id>
+	    <enable-calendar>true</enable-calendar>
+	    <enable-addressbook>true</enable-addressbook>
+	</record>
+	<record>
+	    <uid>puser01</uid>
+	    <server-id>B</server-id>
+	    <enable-calendar>true</enable-calendar>
+	    <enable-addressbook>true</enable-addressbook>
+	</record>
+	<record>
+	    <uid>puser02</uid>
+	    <server-id>B</server-id>
+	    <enable-calendar>true</enable-calendar>
+	    <enable-addressbook>true</enable-addressbook>
+	</record>
+	<record>
+	    <uid>puser03</uid>
+	    <server-id>B</server-id>
+	    <enable-calendar>true</enable-calendar>
+	    <enable-addressbook>true</enable-addressbook>
+	</record>
+	<record>
+	    <uid>puser04</uid>
+	    <server-id>B</server-id>
+	    <enable-calendar>true</enable-calendar>
+	    <enable-addressbook>true</enable-addressbook>
+	</record>
+	<record>
+	    <uid>puser05</uid>
+	    <server-id>B</server-id>
+	    <enable-calendar>true</enable-calendar>
+	    <enable-addressbook>true</enable-addressbook>
+	</record>
+	<record>
+	    <uid>puser06</uid>
+	    <server-id>B</server-id>
+	    <enable-calendar>true</enable-calendar>
+	    <enable-addressbook>true</enable-addressbook>
+	</record>
+	<record>
+	    <uid>puser07</uid>
+	    <server-id>B</server-id>
+	    <enable-calendar>true</enable-calendar>
+	    <enable-addressbook>true</enable-addressbook>
+	</record>
+	<record>
+	    <uid>puser08</uid>
+	    <server-id>B</server-id>
+	    <enable-calendar>true</enable-calendar>
+	    <enable-addressbook>true</enable-addressbook>
+	</record>
+	<record>
+	    <uid>puser09</uid>
+	    <server-id>B</server-id>
+	    <enable-calendar>true</enable-calendar>
+	    <enable-addressbook>true</enable-addressbook>
+	</record>
+	<record>
+	    <uid>puser10</uid>
+	    <server-id>B</server-id>
+	    <enable-calendar>true</enable-calendar>
+	    <enable-addressbook>true</enable-addressbook>
+	</record>
+</augments>

Modified: CalendarServer/branches/users/cdaboo/pod2pod-migration/txdav/common/datastore/podding/migration/test/accounts/groupAccounts.xml
===================================================================
--- CalendarServer/branches/users/cdaboo/pod2pod-migration/txdav/common/datastore/podding/migration/test/accounts/groupAccounts.xml	2015-02-27 22:12:30 UTC (rev 14487)
+++ CalendarServer/branches/users/cdaboo/pod2pod-migration/txdav/common/datastore/podding/migration/test/accounts/groupAccounts.xml	2015-02-28 16:38:15 UTC (rev 14488)
@@ -137,4 +137,74 @@
 	    <member-uid>group03</member-uid>
 	    <member-uid>user10</member-uid>
 	</record>
+	<record type="user">
+	    <uid>puser01</uid>
+	    <short-name>puser01</short-name>
+	    <password>puser01</password>
+	    <full-name>Puser 01</full-name>
+	    <email>puser01 at example.com</email>
+	</record>
+	<record type="user">
+	    <uid>puser02</uid>
+	    <short-name>puser02</short-name>
+	    <password>puser02</password>
+	    <full-name>Puser 02</full-name>
+	    <email>puser02 at example.com</email>
+	</record>
+	<record type="user">
+	    <uid>puser03</uid>
+	    <short-name>puser03</short-name>
+	    <password>puser03</password>
+	    <full-name>Puser 03</full-name>
+	    <email>puser03 at example.com</email>
+	</record>
+	<record type="user">
+	    <uid>puser04</uid>
+	    <short-name>puser04</short-name>
+	    <password>puser04</password>
+	    <full-name>Puser 04</full-name>
+	    <email>puser04 at example.com</email>
+	</record>
+	<record type="user">
+	    <uid>puser05</uid>
+	    <short-name>puser05</short-name>
+	    <password>puser05</password>
+	    <full-name>Puser 05</full-name>
+	    <email>puser05 at example.com</email>
+	</record>
+	<record type="user">
+	    <uid>puser06</uid>
+	    <short-name>puser06</short-name>
+	    <password>puser06</password>
+	    <full-name>Puser 06</full-name>
+	    <email>puser06 at example.com</email>
+	</record>
+	<record type="user">
+	    <uid>puser07</uid>
+	    <short-name>puser07</short-name>
+	    <password>puser07</password>
+	    <full-name>Puser 07</full-name>
+	    <email>puser07 at example.com</email>
+	</record>
+	<record type="user">
+	    <uid>puser08</uid>
+	    <short-name>puser08</short-name>
+	    <password>puser08</password>
+	    <full-name>Puser 08</full-name>
+	    <email>puser08 at example.com</email>
+	</record>
+	<record type="user">
+	    <uid>puser09</uid>
+	    <short-name>puser09</short-name>
+	    <password>puser09</password>
+	    <full-name>Puser 09</full-name>
+	    <email>puser09 at example.com</email>
+	</record>
+	<record type="user">
+	    <uid>puser10</uid>
+	    <short-name>puser10</short-name>
+	    <password>puser10</password>
+	    <full-name>Puser 10</full-name>
+	    <email>puser10 at example.com</email>
+	</record>
 </directory>

Modified: CalendarServer/branches/users/cdaboo/pod2pod-migration/txdav/common/datastore/podding/migration/test/test_home_sync.py
===================================================================
--- CalendarServer/branches/users/cdaboo/pod2pod-migration/txdav/common/datastore/podding/migration/test/test_home_sync.py	2015-02-27 22:12:30 UTC (rev 14487)
+++ CalendarServer/branches/users/cdaboo/pod2pod-migration/txdav/common/datastore/podding/migration/test/test_home_sync.py	2015-02-28 16:38:15 UTC (rev 14488)
@@ -23,12 +23,13 @@
 from twistedcaldav.config import config
 from twistedcaldav.ical import Component, normalize_iCalStr
 from txdav.caldav.datastore.sql import ManagedAttachment
+from txdav.caldav.datastore.sql_directory import GroupShareeRecord
 from txdav.common.datastore.podding.migration.home_sync import CrossPodHomeSync
 from txdav.common.datastore.podding.migration.sync_metadata import CalendarMigrationRecord, \
     AttachmentMigrationRecord
 from txdav.common.datastore.podding.test.util import MultiStoreConduitTest
 from txdav.common.datastore.sql_directory import DelegateRecord, \
-    ExternalDelegateGroupsRecord, DelegateGroupsRecord
+    ExternalDelegateGroupsRecord, DelegateGroupsRecord, GroupsRecord
 from txdav.common.datastore.sql_notification import NotificationCollection
 from txdav.common.datastore.sql_tables import schema, _HOME_STATUS_EXTERNAL, \
     _BIND_MODE_READ, _HOME_STATUS_MIGRATING
@@ -983,21 +984,55 @@
     """
 
     @inlineCallbacks
-    def _createShare(self, shareFrom, shareTo):
+    def setUp(self):
+        self.accounts = FilePath(__file__).sibling("accounts").child("groupAccounts.xml")
+        self.augments = FilePath(__file__).sibling("accounts").child("augments.xml")
+        yield super(TestSharingSync, self).setUp()
+        yield self.populate()
+
+
+    def configure(self):
+        super(TestSharingSync, self).configure()
+        config.Sharing.Enabled = True
+        config.Sharing.Calendars.Enabled = True
+        config.Sharing.Calendars.Groups.Enabled = True
+        config.Sharing.Calendars.Groups.ReconciliationDelaySeconds = 0
+
+
+    @inlineCallbacks
+    def populate(self):
+        yield populateCalendarsFrom(self.requirements, self.theStoreUnderTest(0))
+
+    requirements = {
+        "user01" : None,
+        "user02" : None,
+        "user06" : None,
+        "user07" : None,
+        "user08" : None,
+        "user09" : None,
+        "user10" : None,
+    }
+
+
+    @inlineCallbacks
+    def _createShare(self, shareFrom, shareTo, accept=True):
         # Invite
         txnindex = 1 if shareFrom[0] == "p" else 0
         home = yield self.homeUnderTest(txn=self.theTransactionUnderTest(txnindex), name=shareFrom, create=True)
         calendar = yield home.childWithName("calendar")
         shareeView = yield calendar.inviteUIDToShare(shareTo, _BIND_MODE_READ, "summary")
-        inviteUID = shareeView.shareUID()
         yield self.commitTransaction(txnindex)
 
         # Accept
-        txnindex = 1 if shareTo[0] == "p" else 0
-        shareeHome = yield self.homeUnderTest(txn=self.theTransactionUnderTest(txnindex), name=shareTo)
-        shareeView = yield shareeHome.acceptShare(inviteUID)
-        sharedName = shareeView.name()
-        yield self.commitTransaction(txnindex)
+        if accept:
+            inviteUID = shareeView.shareUID()
+            txnindex = 1 if shareTo[0] == "p" else 0
+            shareeHome = yield self.homeUnderTest(txn=self.theTransactionUnderTest(txnindex), name=shareTo)
+            shareeView = yield shareeHome.acceptShare(inviteUID)
+            sharedName = shareeView.name()
+            yield self.commitTransaction(txnindex)
+        else:
+            sharedName = None
 
         returnValue(sharedName)
 
@@ -1073,7 +1108,42 @@
         yield self.commitTransaction(1)
 
 
+    @inlineCallbacks
+    def test_group_shared_collections_reconcile(self):
+        """
+        Test that L{sharedCollectionsReconcile} copies over the full set of delegates and caches associated groups..
+        """
 
+        # Create home
+        yield self.homeUnderTest(txn=self.theTransactionUnderTest(0), name="user01", create=True)
+        yield self.commitTransaction(0)
+
+        # Shared by migrating user
+        yield self._createShare("user01", "group02", accept=False)
+
+        # Sync from remote side
+        syncer = CrossPodHomeSync(self.theStoreUnderTest(1), "user01")
+        yield syncer.loadRecord()
+        yield syncer.sync()
+        changes = yield syncer.sharedByCollectionsReconcile()
+        self.assertEqual(changes, 3)
+        changes = yield syncer.sharedToCollectionsReconcile()
+        self.assertEqual(changes, 0)
+
+        # Local calendar exists with shares
+        home1 = yield self.homeUnderTest(txn=self.theTransactionUnderTest(1), name="user01", status=_HOME_STATUS_MIGRATING)
+        calendar1 = yield home1.childWithName("calendar")
+        invites1 = yield calendar1.sharingInvites()
+        self.assertEqual(len(invites1), 3)
+        sharee = yield GroupShareeRecord.querysimple(self.theTransactionUnderTest(1), calendarID=calendar1.id())
+        self.assertEqual(len(sharee), 1)
+        group = yield GroupsRecord.querysimple(self.theTransactionUnderTest(1), groupID=sharee[0].groupID)
+        self.assertEqual(len(group), 1)
+        self.assertEqual(group[0].groupUID, "group02")
+        yield self.commitTransaction(1)
+
+
+
 class TestGroupAttendeeSync(MultiStoreConduitTest):
     """
     GroupAttendeeReconciliation tests
@@ -1155,7 +1225,6 @@
         "user08" : None,
         "user09" : None,
         "user10" : None,
-
     }
 
     @inlineCallbacks

Modified: CalendarServer/branches/users/cdaboo/pod2pod-migration/txdav/common/datastore/podding/store_api.py
===================================================================
--- CalendarServer/branches/users/cdaboo/pod2pod-migration/txdav/common/datastore/podding/store_api.py	2015-02-27 22:12:30 UTC (rev 14487)
+++ CalendarServer/branches/users/cdaboo/pod2pod-migration/txdav/common/datastore/podding/store_api.py	2015-02-28 16:38:15 UTC (rev 14488)
@@ -169,6 +169,7 @@
 UtilityConduitMixin._make_simple_action(StoreAPIConduitMixin, "homechild_search", "search")
 UtilityConduitMixin._make_simple_action(StoreAPIConduitMixin, "homechild_sharing_records", "sharingBindRecords", transform_recv_result=StoreAPIConduitMixin._to_serialize_dict_value)
 UtilityConduitMixin._make_simple_action(StoreAPIConduitMixin, "homechild_migrate_sharing_records", "migrateBindRecords")
+UtilityConduitMixin._make_simple_action(StoreAPIConduitMixin, "homechild_group_sharees", "groupSharees", transform_recv_result=StoreAPIConduitMixin._to_serialize_dict_list_serialized_value)
 
 # Calls on L{CommonObjectResource} objects
 UtilityConduitMixin._make_simple_action(StoreAPIConduitMixin, "objectresource_loadallobjects", "loadAllObjects", classMethod=True, transform_recv_result=UtilityConduitMixin._to_serialize_list)

Modified: CalendarServer/branches/users/cdaboo/pod2pod-migration/txdav/common/datastore/podding/test/util.py
===================================================================
--- CalendarServer/branches/users/cdaboo/pod2pod-migration/txdav/common/datastore/podding/test/util.py	2015-02-27 22:12:30 UTC (rev 14487)
+++ CalendarServer/branches/users/cdaboo/pod2pod-migration/txdav/common/datastore/podding/test/util.py	2015-02-28 16:38:15 UTC (rev 14488)
@@ -129,6 +129,7 @@
     theStores = []
     activeTransactions = []
     accounts = None
+    augments = None
 
     def __init__(self, methodName='runTest'):
         txweb2.dav.test.util.TestCase.__init__(self, methodName)
@@ -156,6 +157,7 @@
                     serversDB=serversDB,
                     storeBuilder=self.theStoreBuilders[i],
                     accounts=self.accounts,
+                    augments=self.augments,
                 )
                 self.theStores[i] = self.store
             else:
@@ -165,6 +167,7 @@
                     self.mktemp(),
                     serversDB=serversDB,
                     accounts=self.accounts,
+                    augments=self.augments,
                 )
                 self.theStores[i].setDirectoryService(directory)
 
-------------- next part --------------
An HTML attachment was scrubbed...
URL: <https://lists.macosforge.org/pipermail/calendarserver-changes/attachments/20150228/2cc80969/attachment-0001.html>


More information about the calendarserver-changes mailing list
--- CalendarServer/branches/users/cdaboo/pod2pod-migration/txdav/common/datastore/podding/migration/home_sync.py	2015-02-27 22:12:30 UTC (rev 14487)
+++ CalendarServer/branches/users/cdaboo/pod2pod-migration/txdav/common/datastore/podding/migration/home_sync.py	2015-02-28 16:38:15 UTC (rev 14488)
@@ -179,13 +179,10 @@
         # Delegates reconcile
         yield self.delegateReconcile()
 
         # TODO: shared collections reconcile
         yield self.sharedByCollectionsReconcile()
         yield self.sharedToCollectionsReconcile()
 
-        # TODO: group sharee reconcile
-        pass
-
         # Notifications
         yield self.notificationsReconcile()
 
@@ -977,6 +974,9 @@
                 yield self.makeSharedByCollections(records[:50], calendar.localResourceID)
                 records = records[50:]
 
+            # Get groups from remote pod
+            yield self.syncGroupSharees(calendar.remoteResourceID, calendar.localResourceID)
+
             # Update the remote pod to switch over the shares
             yield self.updatedRemoteSharedByCollections(calendar.remoteResourceID, bindUID)
 
@@ -1043,6 +1043,23 @@
 
     @inTransactionWrapper
     @inlineCallbacks
+    def syncGroupSharees(self, txn, remote_id, local_id):
+        """
+        Sync the group sharees for a remote share.
+        """
+        remote_home = yield self._remoteHome(txn)
+        remote_calendar = yield remote_home.childWithID(remote_id)
+        results = yield remote_calendar.groupSharees()
+        groups = dict([(group.groupID, group.groupUID,) for group in results["groups"]])
+        for share in results["sharees"]:
+            local_group = yield txn.groupByUID(groups[share.groupID])
+            share.groupID = local_group.groupID
+            share.calendarID = local_id
+            yield share.insert(txn)
+
+
+    @inTransactionWrapper
+    @inlineCallbacks
     def updatedRemoteSharedByCollections(self, txn, remote_id, bindUID):
         """
         Get all the existing L{CalendarBindRecord}'s from the remote store.
@@ -179,13 +179,10 @@
         yield self.delegateReconcile()
 
-        # TODO: shared collections reconcile
+        # Shared collections reconcile (including group sharees)
         yield self.sharedByCollectionsReconcile()
         yield self.sharedToCollectionsReconcile()

Added: CalendarServer/branches/users/cdaboo/pod2pod-migration/txdav/common/datastore/podding/migration/test/accounts/augments.xml
===================================================================